summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorDonald Sarratt <donald.sarratt@nzx.com>2017-11-08 18:46:32 +1300
committerDonald Sarratt <donald.sarratt@nzx.com>2017-11-08 18:46:32 +1300
commit8a7a86bf5db5ef7518c9e221912cc6edba4b8675 (patch)
treef33ff22708429e0cc107f4f7122799b0fc2c8532
parent2e691016d18749e8a46b99749ed3aa5656ad1cb0 (diff)
downloadyoyo-8a7a86bf5db5ef7518c9e221912cc6edba4b8675.tar.gz
Exclude the CREATE DATABASE test from Oracle.
-rw-r--r--yoyo/tests/test_backends.py4
1 files changed, 2 insertions, 2 deletions
diff --git a/yoyo/tests/test_backends.py b/yoyo/tests/test_backends.py
index 63fbfe4..d4027b0 100644
--- a/yoyo/tests/test_backends.py
+++ b/yoyo/tests/test_backends.py
@@ -105,10 +105,10 @@ class TestTransactionHandling(object):
are run within a transaction block.
As far as I know this behavior is PostgreSQL specific. We can't run
this test in sqlite as it does not support CREATE DATABASE.
"""
from yoyo import read_migrations
- for backend in get_test_backends(exclude={'sqlite'}):
+ for backend in get_test_backends(exclude={'sqlite', 'oracle'}):
migrations = read_migrations(tmpdir)
backend.apply_migrations(migrations)
backend.rollback_migrations(migrations)
@@ -105,10 +105,10 @@ class TestTransactionHandling(object):
are run within a transaction block.
As far as I know this behavior is PostgreSQL specific. We can't run
- this test in sqlite as it does not support CREATE DATABASE.
+ this test in sqlite or oracle as they do not support CREATE DATABASE.
"""
from yoyo import read_migrations